pymrio.MRIOMetaData
===================

.. currentmodule:: pymrio

.. autoclass:: MRIOMetaData

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MRIOMetaData.__init__
      ~MRIOMetaData.change_meta
      ~MRIOMetaData.note
      ~MRIOMetaData.save
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~MRIOMetaData.description
      ~MRIOMetaData.file_io_history
      ~MRIOMetaData.history
      ~MRIOMetaData.metadata
      ~MRIOMetaData.modification_history
      ~MRIOMetaData.name
      ~MRIOMetaData.note_history
      ~MRIOMetaData.system
      ~MRIOMetaData.version
   
   